.. _developers-guide-index:

####################################
  The Matplotlib Developers' Guide
####################################

.. htmlonly::

   :Release: |version|
   :Date: |today|

.. toctree::
   :maxdepth: 2

   coding_guide.rst
   gitwash/index.rst
   documenting_mpl.rst
   release_guide.rst
   transformations.rst
   add_new_projection.rst
   outline.rst
